===============================
prediction_coefficient
===============================


.. image:: https://img.shields.io/travis/ForDataScience/prediction_coefficient.svg
        :target: https://travis-ci.org/ForDataScience/prediction_coefficient
.. image:: https://circleci.com/gh/ForDataScience/prediction_coefficient.svg?style=svg
    :target: https://circleci.com/gh/ForDataScience/prediction_coefficient
.. image:: https://codecov.io/gh/ForDataScience/prediction_coefficient/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/ForDataScience/prediction_coefficient


A categorical correlation coefficient that's in the same range for all pairs of variables (from 0 to 1), regardless of their degrees of freedom or the chosen confidence level.
